django-geckoboard
=================

Geckoboard_ is a hosted, real-time status board serving up indicators
from web analytics, CRM, support, infrastructure, project management,
sales, etc.  It can be connected to virtually any source of quantitative
data.

This Django application provides view decorators to help create custom
widgets.  You can install the package from the `PyPI page`_::

    $ easy_install django-geckoboard

Or use Git to get the development version from the `project page`_::

    $ git clone git://github.com/jcassee/django-geckoboard.git

See the ``geckoboard`` package docstring or the `PyPI page`_ for
documentation.

If you want to help out with the development of django-geckoboard, by
posting detailed bug reports, proposing new features or other analytics
services to support, or suggesting documentation improvements, please
use the `issue tracker`_.  If you want to get your hands dirty, great!
Clone the repository, make changes and send a pull request.  Please do
create an issue to discuss your plans.

Copyright (C) 2011 Joost Cassee <joost@cassee.net>.  This software is
licensed under the MIT License (see LICENSE.txt).

Thanks go to Geckoboard for their support, and to GitHub for hosting the
project source code and issue tracker.

.. _Django: http://www.djangoproject.com/
.. _Geckoboard: http://www.geckoboard.com/
.. _`PyPI page`: http://pypi.python.org/pypi/django-geckoboard
.. _`project page`: http://github.com/jcassee/django-geckoboard
.. _`issue tracker`: http://github.com/jcassee/django-geckoboard/issues
